@@ -65,7 +65,7 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, collectio
     return return_list
 
 
-def two_way(operation):
+def two_way(operation, opposite=False, iterators=False):
     import warnings
     warnings.filterwarnings("ignore")
     import re, keyword
@@ -73,29 +73,32 @@ def two_way(operation):
     failed = defaultdict(set)
     succeeded = defaultdict(set)
     invalid = 'Error|Warning|Exception|Exit|Interrupt|__|ipython|display|execfile|dreload|help|license|open' \
-              '|get_ipython|credits|runfile|copyright|breakpoint|input|print '
-    bytes_iterator = (iter(b''))
-    bytearray_iterator = (iter(bytearray()))
-    dict_keyiterator = (iter({}.keys()))
-    dict_valueiterator = (iter({}.values()))
-    dict_itemiterator = (iter({}.items()))
-    list_iterator = (iter([]))
-    list_reverseiterator = (iter(reversed([])))
-    range_iterator = (iter(range(0)))
-    longrange_iterator = (iter(range(1 << 1000)))
-    set_iterator = (iter(set()))
-    str_iterator = (iter(""))
-    tuple_iterator = (iter(()))
-    zip_iterator = (iter(zip()))
+              '|get_ipython|credits|runfile|copyright|breakpoint|input|print'
+    bytes_iterator = "(iter(b''))"
+    bytearray_iterator = "(iter(bytearray()))"
+    dict_keyiterator = "(iter({}.keys()))"
+    dict_valueiterator = "(iter({}.values()))"
+    dict_itemiterator = "(iter({}.items()))"
+    list_iterator = "(iter([]))"
+    list_reverseiterator = "(iter(reversed([])))"
+    range_iterator = "(iter(range(0)))"
+    set_iterator = "(iter(set()))"
+    str_iterator = "(iter(''))"
+    tuple_iterator = "(iter(()))"
+    zip_iterator = "(iter(zip()))"
+    line_iterator = "(lambda x: 1).__code__.co_lines"
+    positions_iterator = "(lambda x: 1).__code__.co_positions"
     ## views ##
     dict_keys = 'dict().keys'
     dict_values = 'dict().values'
     dict_items = 'dict().items'
-    y = [(bytes_iterator, 0), (bytearray_iterator, 1), (dict_keyiterator, 2),
-         (dict_valueiterator, 3), (dict_itemiterator, 4), (list_iterator, 5),
-         (list_reverseiterator, 6), (range_iterator, 7), (longrange_iterator, 8),
-         (set_iterator, 9), (str_iterator, 10), (tuple_iterator, 11), (zip_iterator, 12),
-         (dict_keys, 13), (dict_values, 14), (dict_items, 15)]
+    y = [(dict_keys, 13), (dict_values, 14), (dict_items, 15)]
+    if iterators:
+        y += [(bytes_iterator, 0), (bytearray_iterator, 1), (dict_keyiterator, 2),
+              (dict_valueiterator, 3), (dict_itemiterator, 4), (list_iterator, 5),
+              (list_reverseiterator, 6), (range_iterator, 7),
+              (set_iterator, 9), (str_iterator, 10), (tuple_iterator, 11), (zip_iterator, 12)]
+
     for a, i in list(keyword.__builtins__.items()) + y:
         a = str(a)
         if not re.search(invalid, str(a)):
@@ -105,26 +108,38 @@ def two_way(operation):
                 if not re.search(invalid, b):
                     try:
                         x = eval(f'{a}() {operation} {b}()')
-                        succeeded[f'{a}()'].add(f'{b}()')
+                        if opposite:
+                            succeeded[f'{b}()'].add(f'{a}()')
+                        else:
+                            succeeded[f'{a}()'].add(f'{b}()')
                     except:
                         t = 1
                         failed[a].add(b)
                     try:
                         x = eval(f'{a}() {operation} {b}')
-                        succeeded[f'{a}()'].add(b)
+                        if opposite:
+                            succeeded[b].add(f'{a}()')
+                        else:
+                            succeeded[f'{a}()'].add(b)
                     except:
                         t1 = 1
                         failed[a].add(b)
                     try:
                         x = eval(f'{a} {operation} {b}()')
-                        succeeded[a].add(f'{b}()')
+                        if opposite:
+                            succeeded[f'{b}()'].add(a)
+                        else:
+                            succeeded[a].add(f'{b}()')
                     except:
                         t2 = 1
                         failed[a].add(b)
                     if t and t1 and t2:
-                      try:
-                          x = eval(f'{a} {operation} {b}')
-                          succeeded[a].add(b)
-                      except:
-                          failed[a].add(b)
-    return [{'succeeded': succeeded}]
+                        try:
+                            x = eval(f'{a} {operation} {b}')
+                            if opposite:
+                                succeeded[b].add(a)
+                            else:
+                                succeeded[a].add(b)
+                        except:
+                            failed[a].add(b)
+    return [{'succeeded': succeeded}]
\ No newline at end of file
